@@ -1,14 +1,12 @@
 from .src import tree_util, tree_viz
 from .src.decorator import treeclass
-from .src.tree_util import static_field, static_value
+from .src.misc import static_field
 
 __all__ = (
-    "tree_viz",
     "treeclass",
-    "static_value",
     "static_field",
     "tree_viz",
     "tree_util",
 )
 
-__version__ = "0.0.11"
+__version__ = "0.1.0"
